@@ -20,11 +20,13 @@
 
 #include <KAboutData>
 #include <KAuthExecuteJob>
+#include <KIO/ApplicationLauncherJob>
 #include <KLocalizedString>
 #include <KPluginFactory>
+#include <KService>
 #include <KUser>
 
-K_PLUGIN_FACTORY_WITH_JSON(KCMSddmFactory, "kcm_sddm.json", registerPlugin<SddmKcm>(); registerPlugin<SddmData>();)
+K_PLUGIN_FACTORY_WITH_JSON(KCMSddmFactory, "../kcm_sddm.json", registerPlugin<SddmKcm>(); registerPlugin<SddmData>();)
 
 SddmKcm::SddmKcm(QObject *parent, const QVariantList &args)
     : KQuickAddons::ManagedConfigModule(parent, args)
@@ -316,4 +318,16 @@ void SddmKcm::resetSyncronizedSettings()
     job->start();
 }
 
+bool SddmKcm::KDEWalletAvailable()
+{
+    return !QStandardPaths::findExecutable(QLatin1String("kwalletmanager5")).isEmpty();
+}
+
+void SddmKcm::openKDEWallet()
+{
+    KService::Ptr kwalletmanagerService = KService::serviceByDesktopName(QStringLiteral("org.kde.kwalletmanager5"));
+    auto *job = new KIO::ApplicationLauncherJob(kwalletmanagerService);
+    job->start();
+}
+
 #include "sddmkcm.moc"
